# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class NotificationAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('subject',)
    advanced_search_fields = (
        ('status',),
        ('subject__icontains',),
        ('type__name__icontains',)
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('type', ('subject', 'slug'), 'body', 'call_to_action_label', 'call_to_action_url')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'type', 'subject', 'ordering')
    list_display_links = ('subject',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {"slug": ("subject",)}
    autocomplete_fields = ('type',)


class NotificationRecipientAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('user__last_name', 'user__first_name',)
    advanced_search_fields = (
        ('status',),
        ('user__last_name__icontains', 'user__first_name__icontains',),
        ('notification__subject__icontains',),
        ('reading_date__gte', 'reading_date__lte',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('user', 'notification', 'reading_date')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'notification', 'user', 'reading_date', 'ordering')
    list_display_links = ('user',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('notification', 'user',)


class NotificationTypeAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name__icontains', 'code__icontains',)
    advanced_search_fields = (
        ('status', 'category'),
        ('code__icontains', 'name__icontains',),
        ('description__icontains',),
        ('note__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'category', 'name', 'description', 'note', 'periodicity')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'code', 'category', 'name', 'ordering')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.Notification, NotificationAdmin)
admin.site.register(models.NotificationRecipient, NotificationRecipientAdmin)
admin.site.register(models.NotificationType, NotificationTypeAdmin)
