# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # NOTIFICATION
    def v1_notify_notification_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_notify_notification_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_notify_notification_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_notify_notification_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_notify_notification_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notification-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # NOTIFICATION RECIPIENT

    def v1_notify_notification_recipient_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_notify_notification_recipient_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationrecipient-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # NOTIFICATION TYPE

    def v1_notify_notification_type_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_notify_notification_type_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-notify:notificationtype-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
