# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# NOTIFICATION
class NotificationSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification'
        model = models.Notification
        fields = '__all__'


class NotificationListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_list'
        model = models.Notification
        fields = '__all__'


class NotificationRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_retrieve'
        model = models.Notification
        fields = '__all__'



class NotificationCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_create'
        model = models.Notification
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRetrieveSerializer



class NotificationUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_update'
        model = models.Notification
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRetrieveSerializer



class NotificationPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_partial_update'
        model = models.Notification
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRetrieveSerializer



class NotificationEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_enable'
        model = models.Notification
        fields = ()
        response_serializer = NotificationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class NotificationDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_disable'
        model = models.Notification
        fields = ()
        response_serializer = NotificationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class NotificationLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_light'
        model = models.Notification
        fields = ('id', 'status', 'status_display',)



# NOTIFICATION RECIPIENT
class NotificationRecipientSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient'
        model = models.NotificationRecipient
        fields = '__all__'


class NotificationRecipientListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_list'
        model = models.NotificationRecipient
        fields = '__all__'


class NotificationRecipientRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_retrieve'
        model = models.NotificationRecipient
        fields = '__all__'


class NotificationRecipientCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_create'
        model = models.NotificationRecipient
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRecipientRetrieveSerializer


class NotificationRecipientUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_update'
        model = models.NotificationRecipient
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRecipientRetrieveSerializer


class NotificationRecipientPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_partial_update'
        model = models.NotificationRecipient
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRecipientRetrieveSerializer


class NotificationRecipientEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_enable'
        model = models.NotificationRecipient
        fields = ()
        response_serializer = NotificationRecipientRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class NotificationRecipientDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_disable'
        model = models.NotificationRecipient
        fields = ()
        response_serializer = NotificationRecipientRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class NotificationRecipientLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_light'
        model = models.NotificationRecipient
        fields = ('id', 'status', 'status_display',)


# NOTIFICATION TYPE
class NotificationTypeSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type'
        model = models.NotificationType
        fields = '__all__'


class NotificationTypeListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_list'
        model = models.NotificationType
        fields = '__all__'


class NotificationTypeRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_retrieve'
        model = models.NotificationType
        fields = '__all__'


class NotificationTypeCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_create'
        model = models.NotificationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationTypeRetrieveSerializer


class NotificationTypeUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_update'
        model = models.NotificationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationTypeRetrieveSerializer


class NotificationTypePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_partial_update'
        model = models.NotificationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationTypeRetrieveSerializer


class NotificationTypeEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_enable'
        model = models.NotificationType
        fields = ()
        response_serializer = NotificationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class NotificationTypeDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_disable'
        model = models.NotificationType
        fields = ()
        response_serializer = NotificationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class NotificationTypeLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_light'
        model = models.NotificationType
        fields = ('id', 'status', 'status_display',)
